@@ -58,11 +58,17 @@ class DBBase:
 
     async def connect(self) -> "Connection":
         """Override this method to customize how the connection is open. For instance you could
-        use a connection pool.
+        use a connection pool's acquire method.
         """
         conn_args = await self.get_connection_args()
         return await connect(**conn_args)
 
+    async def disconnect(self):
+        """Override this method to customize how the connection is closed. For instance you could
+        use a connection pool's release method.
+        """
+        await self._conn.close()
+
     async def open(self) -> "DBBase":
         """Opens the connection."""
         if not self._conn:
@@ -72,7 +78,7 @@ class DBBase:
     async def close(self) -> "DBBase":
         """Closes the connection."""
         if self._conn:
-            await self._conn.close()
+            await self.disconnect()
             self._conn = None
         return self
 
